<?php

/**
 * PLugin Name: Fused Shortcodes
 * Author: Anu Sharma
 * Plugin URI:http://fusedpress.com/plugins/shortcodes/
 * Author URI:http://buddydev.com/members/anusharma/
 * Version: 1.0
 * Description: The Shortcode Library for FusedPress/BuddyDev Themes
 */
define('FP_SHORT_CODES_DIR_PATH', plugin_dir_path(__FILE__));

class FPShortCodes {
    private static $instance;
    
    private function __construct() {
        //include files
        $this->includes();
        //register shortcodes
        $this->register_shortcodes();

        //load css
        add_action('wp_print_styles', array($this, 'load_css'));
        //load js
        add_action('wp_print_scripts', array($this, 'load_js'));
    }
    /**
     *
     * @return FPShortCodes 
     */
    public static function get_instance(){
        
        if(!isset(self::$instance))
                self::$instance=new self();
        
        return self::$instance;
    }
    /**
     * Include required files
     */
    private function includes() {

        $includes = array(
            'pass-protect.php',
            'columns.php',
            'toggle.php'
        );

        foreach ($includes as $include)
            include_once(FP_SHORT_CODES_DIR_PATH . $include);
    }

    /**
     * Register  shortcodes
     * 
     */
    private function register_shortcodes() {
        
        //Info Box
        add_shortcode('alert', array($this, 'alertbox'));
        add_shortcode('success', array($this, 'successbox'));
        add_shortcode('error', array($this, 'errorbox'));
        add_shortcode('warning', array($this, 'warningbox'));
        add_shortcode('comment', array($this, 'commentbox'));
        add_shortcode('notice', array($this, 'notice'));
        add_shortcode('info', array($this, 'infobox'));
        add_shortcode('download', array($this, 'downloadbox'));
        add_shortcode('update', array($this, 'updatebox'));
        add_shortcode('sticky', array($this, 'sticky'));
        
         //Typography
        add_shortcode('dropcap', array($this, 'dropcap'));
        add_shortcode('quote', array($this, 'block_quote'));
        add_shortcode('blockquote', array($this, 'block_quote')); 
        add_shortcode('list', array($this, 'genrate_list'));
        add_shortcode('highlight', array($this, 'highlight'));
       
        //Button
        add_shortcode('button', array($this, 'button'));
        
        //tebale & Tesimonial
        add_shortcode('testimonial', array($this, 'testimonial'));
        add_shortcode('table', array($this, 'insert_table'));
       
        //login form
        add_shortcode('login-form', array($this, 'login_box'));
    }

    /**
     * Alert Box
     * @param type $atts
     * @param type $content
     * @return string 
     */
    function alertbox($atts, $content = null) {

        return $this->generate_box($atts, $content, 'alert');
    }

    /**
     * Success Box
     * @param type $atts
     * @param type $content
     * @return string 
     */
    function successbox($atts, $content = null) {

        return $this->generate_box($atts, $content, 'success');
    }

    /**
     * Error Box
     * 
     * @param type $atts
     * @param type $content
     * @return string 
     */
    function errorbox($atts, $content = null) {

        return $this->generate_box($atts, $content, 'error');
    }

    /**
     * Warning Box
     * 
     * @param type $atts
     * @param type $content
     * @return type 
     */
    function warningbox($atts, $content = null) {

        return $this->generate_box($atts, $content, 'warningbox');
    }

    /**
     * Comment Box
     * 
     * @param type $atts
     * @param type $content
     * @return type 
     */
    function commentbox($atts, $content = null) {

        return $this->generate_box($atts, $content, 'commentbox');
    }

    /**
     * Notice Box
     * 
     * @param type $atts
     * @param type $content
     * @param type $code
     * @return type 
     */
    function notice($atts, $content = null, $code = "") {

        return $this->generate_box($atts, $content, 'notice');
    }

    /**
     * Update Box
     * 
     * @param type $atts
     * @param type $content
     * @param type $code
     * @return type 
     */
    function updatebox($atts, $content = null, $code = "") {

        return $this->generate_box($atts, $content, 'updatebox');
    }

    /**
     * Info Box blue
     * 
     * @param type $atts
     * @param type $content
     * @param type $code
     * @return type 
     */
    function infobox($atts, $content = null, $code = "") {

        return $this->generate_box($atts, $content, 'info');
    }

    /**
     * Download Box
     * 
     * @param type $atts
     * @param type $content
     * @param type $code
     * @return type 
     */
    function downloadbox($atts, $content = null, $code = "") {

        return $this->generate_box($atts, $content, 'download');
    }

    /**
     * Sticky Box
     * 
     * @param type $atts
     * @param type $content
     * @param type $code
     * @return type 
     */
    function sticky($atts, $content = null, $code = "") {

        return $this->generate_box($atts, $content, 'sticky');
    }

    /**
     * Generate Box
     * 
     * @param type $atts
     * @param type $content
     * @param type $class_name
     * @return type 
     */
    public function generate_box($atts, $content, $class_name) {
        $default = array(
            'name' => '',
            'class' => ''
        );

        $args = shortcode_atts($default, $atts);
        extract($args);
        $return = "<div class='ui-sc ui-sc-box ui-sc-box-{$class_name} {$class}'>{$content}</div>";
        return $return;
    }

    /**
     * Drop Cap Small
     * 
     * @param type $atts
     * @param type $content
     * @return type 
     */
    function dropcap($atts, $content = null) {

        extract(shortcode_atts(array(
                    'style' => '',
                    'id' => '',
                    'type' => '',
                    'class' => ''
                        ), $atts));

        $style = ( $style != '' ) ? ' style="' . $style . '"' : '';
        $id = ($id != '') ? " id='" . esc_attr($id) . "'" : '';
        $class = ($class != '') ? esc_attr(' ' . $class) : '';

        $output = "<span{$id} class='ui-sc ui-sc-dropcap {$class} {$type}'{$style}>{$content}</span>";

        return $output;
    }

    /**
     * button 
     * 
     * @param type $atts
     * @param type $content
     * @return type 
     */
    function button($atts, $content = null) {

        extract(shortcode_atts(array(
                    "link" => "#",
                    "color" => "",
                    "type" => "",
                    "icon" => "",
                    "newwindow" => "",
                    "id" => '',
                    "class" => '',
                    'align' => '',
                    "br" => 'no'
                        ), $atts));

        $output = '';
        $target = ($newwindow == 'yes') ? ' target="_blank"' : '';


        $id = ($id != '') ? " id='" . esc_attr($id) . "'" : '';
        $class = ($class != '') ? esc_attr(' ' . $class) : '';

        if ($type == 'small')
            $output .= "<a{$id} href='{$link}' class='ui-sc-button ui-sc-small-button {$color} {$class} {$align}'{$target}>{$content}</a>";

        if ($type == 'medium')
            $output .= "<a{$id} href='{$link}' class='ui-sc-button ui-sc-medium-button {$color} {$class} {$align} '{$target}>{$content}</a>";

        if ($type == 'large')
            $output .= "<a{$id} href='{$link}' class='ui-sc-button ui-sc-large-button {$color} {$class} {$align}'{$target}>{$content}</a>";

        if ($type == 'icon')
            $output .= "<a{$id} href='{$link}' class='icon-button {$icon} {$color} {$class}'{$target}>{$content}<span class='ui-sc-button'></span></a>";

        if ($br == 'yes')
            $output .= '<br class="clear"/>';

        return $output;
    }

    /**
     * quote 
     * 
     * @param type $atts
     * @param type $content
     * @return type 
     */
    function block_quote($atts, $content = null) {

        extract(shortcode_atts(array(
                    'size' => '', // full width 100% is default
                    'color' => '',
                    'type' => '',
                    'align' => '',
                    'float' => '',
                    'text' => '',
                    'class' => '',
                    'pullquote' => '',
                    'image' => ','
                        ), $atts));

        $style = "";

        if (!empty($size))
            $style.="font-size:{$size};";

        if (!empty($color))
            $style.="color:{$color};";

        if (!empty($align))
            $style.="text-align:{$align};";

        if (!empty($pullquote))
            $style.="pullquote:{$pullquote};";

        if (!empty($float))
            $style = "float:{$float};";

        $class = ($class) ? $class : '';

        return "<blockqoute class='ui-sc ui-sc-quote {$class}' style='{$style}'><span class='ui-sc-qoute-icon '></span><span class='ui-sc-quote-content'>" . $content . "</span></blockqoute>";
    }

    /**
     * testimonial
     * 
     * @param type $atts
     * @param type $content
     * @return type
     */
    function testimonial($atts, $content = null) {

        extract(shortcode_atts(array(
                    'img' => '',
                    'name' => '',
                    'website' => '',
                    'alt' => 'testimonial',
                    'class' => ''
                        ), $atts));
        $by_line='';

        if (isset($img)) {

            $img_style = "<p><img src=\"$img\" height=\"60px\" width=\"60\" border=\"0\" alt=\"$alt\" /></a></p>";
        }

        if ($name != "") {

            $by_line = "<br><p style=\"padding: 0px;\" align=\"right\"><strong><em>~ $name, <a href=\"$website\">$website</a></em></strong></p>";
        }

        $class = ($class) ? $class : '';

        return "<div  class='ui-sc ui-sc-testimonial'>$img_style <i>$content</i> $by_line</div>";
    }

    /**
     * List
     * 
     * @param type $atts
     * @param type $content
     * @return type
     */
    function genrate_list($atts, $content = null) {

        extract(shortcode_atts(array("type" => 'checkmark'), $atts));

        $type = ( $type != 'checkmark' ) ? ' list-' . $type : '';

        $output = "
		<div class='ui-sc-custom-list{$type}'>
		{$content}
		</div> <!-- .ui-sc-custom-list -->";

        return $output;
    }

    /**
     * text  highlight
     * 
     * @param type $atts
     * @param type $content
     * @return type
     */
    function highlight($atts, $content = null) {

        extract(shortcode_atts(array("color" => '1', 'class' => ''), $atts));

        $html = '<span class="ui-sc ui-sc-highlight' . $atts{color} . '">' . $content . '</span>';

        return ($html);
    }

    /**
     * table
     * 
     * @global type $class
     * @param type $atts
     * @return string
     * 
     * syntax for use [table cols="name,quantity,price," data="name1,5,2.00,name2,3,3.25"]
     */
    function insert_table($atts) {

        extract(shortcode_atts(array('cols' => 'none', 'data' => 'none',), $atts));

        $cols = explode(',', $cols);
        $data = explode(',', $data);

        $ncols = count($cols);
        $ndata = count($data);
        $nrows = $ndata / $ncols;

        global $class;

        $html = "<table class='ui-sc-table <?php echo $class;?>'>";
        //for each row
        $html.="<tr>";

        foreach ($cols as $col)
            $html.="<th>{$col}</th>";

        $html.="</tr>";

        for ($i = 0; $i < $nrows; $i++) {

            $low = $i * $ncols;
            $up = ($i + 1) * $ncols - 1;
            $html.= "<tr>";
           
            for (; $low <= $up; $low++)
                $html.= "<td>" . $data[$low] . "</td>";

            $html.= "</tr>";
        }

        $html.= "</table>";
        return $html;
    }

    /**
     * Login Form
     * @param type $atts
     * @param type $content
     * @return type 
     */
    function login_box($atts, $content = null) {

        $login = wp_login_form(array(
            'echo' => false,
            'redirect' => site_url($_SERVER['REQUEST_URI']),
            'form_id' => 'loginform',
            'label_username' => __('Username'),
            'label_password' => __('Password'),
            'label_remember' => __('Remember Me'),
            'label_log_in' => __('Log In'),
            'id_username' => 'user_login',
            'id_password' => 'user_pass',
            'id_remember' => 'rememberme',
            'id_submit' => 'wp-submit',
            'remember' => true,
                ));

        return $login;
    }

    /**
     * Load CSS
     */
    function load_css() {
        wp_enqueue_style('fp-shortcodes-css', plugin_dir_url(__FILE__) . '_inc/css/shortcode.css');
    }

    /**
     * Load Js
     */
    function load_js() {
        wp_enqueue_script('fp-shortcode-js', plugin_dir_url(__FILE__) . '_inc/js/toggle.js', array('jquery'));
    }

}

FPShortCodes::get_instance();
?>